@@ -17,7 +17,10 @@ class FilterRegressionTests(BaseObject):
         Created:
             6-Jun-2022
             craigtrim@gmail.com
-            *   https://github.com/grafflr/deepnlu/issues/22
+        Updated:
+            13-Sept-2022
+            craigtrim@gmail.com
+            *   migrated to regression-framework repo
         """
         BaseObject.__init__(self, __name__)
 
